@@ -1,26 +1,12 @@
-# Licensed under the Apache License, Version 2.0 (the "License"); you may
-# not use this file except in compliance with the License. You may obtain
-# a copy of the License at
-#
-#      http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-# License for the specific language governing permissions and limitations
-# under the License.
-
 import copy
 
-from django.utils.functional import empty
-from django.utils.functional import LazyObject
-from django.utils.functional import SimpleLazyObject
+from django.utils.functional import LazyObject, empty
 
 
 class LazySettings(LazyObject):
     def _setup(self, name=None):
         from django.conf import settings
-        from horizon.conf.default import HORIZON_CONFIG as DEFAULT_CONFIG
+        from .default import HORIZON_CONFIG as DEFAULT_CONFIG
         HORIZON_CONFIG = copy.copy(DEFAULT_CONFIG)
         HORIZON_CONFIG.update(settings.HORIZON_CONFIG)
 
@@ -45,11 +31,4 @@ class LazySettings(LazyObject):
             self._setup(name)
         return self._wrapped.get(name, fallback)
 
-
-def get_webroot():
-    from django.conf import settings
-    return settings.WEBROOT
-
-
 HORIZON_CONFIG = LazySettings()
-WEBROOT = SimpleLazyObject(get_webroot)
