@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012,  Nachi Ueno,  NTT MCL,  Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -11,10 +13,13 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+import logging
 
 from horizon import tabs
 from openstack_dashboard.dashboards.project.routers.ports import tabs as r_tabs
 
+LOG = logging.getLogger(__name__)
+
 
 class OverviewTab(r_tabs.OverviewTab):
     template_name = "admin/networks/ports/_detail_overview.html"
