@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -16,20 +18,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf.urls import patterns
-from django.conf.urls import url
+from django.conf.urls.defaults import patterns, url
 
-from openstack_dashboard.dashboards.project.access_and_security.\
-    api_access import views
+from .views import download_ec2_bundle, download_rc_file
 
 
-urlpatterns = patterns(
-    '',
-    url(r'^ec2/$', views.download_ec2_bundle, name='ec2'),
-    url(r'^openrc/$', views.download_rc_file, name='openrc'),
-    url(r'^openrcv2/$', views.download_rc_file_v2, name='openrcv2'),
-    url(r'^view_credentials/$', views.CredentialsView.as_view(),
-        name='view_credentials'),
-    url(r'^recreate_ec2_credentials/$',
-        views.RecreateCredentialsView.as_view(), name='recreate_credentials'),
+urlpatterns = patterns('',
+    url(r'^ec2/$', download_ec2_bundle, name='ec2'),
+    url(r'^openrc/$', download_rc_file, name='openrc'),
 )
