@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 #    Copyright 2013, Big Switch Networks, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -12,73 +14,66 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.utils.translation import ugettext_lazy as _
+import re
+
+from django.utils.translation import ugettext as _
 
 from horizon import exceptions
 from horizon import tabs
+from horizon import tables
 
 from openstack_dashboard import api
-from openstack_dashboard.dashboards.project.loadbalancers import tables
+
+from .tables import PoolsTable, MembersTable, MonitorsTable
 
 
 class PoolsTab(tabs.TableTab):
-    table_classes = (tables.PoolsTable,)
+    table_classes = (PoolsTable,)
     name = _("Pools")
     slug = "pools"
     template_name = "horizon/common/_detail_table.html"
 
     def get_poolstable_data(self):
-        pools = []
         try:
-            request = self.tab_group.request
-            tenant_id = self.request.user.tenant_id
-            pools = api.lbaas.pool_list(request,
-                                        tenant_id=tenant_id)
-            fips = None
-            for pool in pools:
-                if hasattr(pool, "vip") and pool.vip:
-                    if not fips:
-                        fips = api.network.tenant_floating_ip_list(request)
-                    vip_fip = [fip for fip in fips
-                               if fip.port_id == pool.vip.port_id]
-                    if vip_fip:
-                        pool.vip.fip = vip_fip[0]
-        except Exception:
+            pools = api.lbaas.pools_get(self.tab_group.request)
+            poolsFormatted = [p.readable(self.tab_group.request) for
+                              p in pools]
+        except:
+            poolsFormatted = []
             exceptions.handle(self.tab_group.request,
                               _('Unable to retrieve pools list.'))
-        return pools
+        return poolsFormatted
 
 
 class MembersTab(tabs.TableTab):
-    table_classes = (tables.MembersTable,)
+    table_classes = (MembersTable,)
     name = _("Members")
     slug = "members"
     template_name = "horizon/common/_detail_table.html"
 
     def get_memberstable_data(self):
         try:
-            tenant_id = self.request.user.tenant_id
-            members = api.lbaas.member_list(self.tab_group.request,
-                                            tenant_id=tenant_id)
-        except Exception:
-            members = []
+            members = api.lbaas.members_get(self.tab_group.request)
+            membersFormatted = [m.readable(self.tab_group.request) for
+                                m in members]
+        except:
+            membersFormatted = []
             exceptions.handle(self.tab_group.request,
                               _('Unable to retrieve member list.'))
-        return members
+        return membersFormatted
 
 
 class MonitorsTab(tabs.TableTab):
-    table_classes = (tables.MonitorsTable,)
+    table_classes = (MonitorsTable,)
     name = _("Monitors")
     slug = "monitors"
     template_name = "horizon/common/_detail_table.html"
 
     def get_monitorstable_data(self):
         try:
-            tenant_id = self.request.user.tenant_id
-            monitors = api.lbaas.pool_health_monitor_list(
-                self.tab_group.request, tenant_id=tenant_id)
-        except Exception:
+            monitors = api.lbaas.pool_health_monitors_get(
+                self.tab_group.request)
+        except:
             monitors = []
             exceptions.handle(self.tab_group.request,
                               _('Unable to retrieve monitor list.'))
@@ -97,17 +92,29 @@ class PoolDetailsTab(tabs.Tab):
     template_name = "project/loadbalancers/_pool_details.html"
 
     def get_context_data(self, request):
-        pool = self.tab_group.kwargs['pool']
+        pid = self.tab_group.kwargs['pool_id']
+        try:
+            pool = api.lbaas.pool_get(request, pid)
+        except:
+            pool = []
+            exceptions.handle(request,
+                              _('Unable to retrieve pool details.'))
         return {'pool': pool}
 
 
 class VipDetailsTab(tabs.Tab):
-    name = _("VIP Details")
+    name = _("Vip Details")
     slug = "vipdetails"
     template_name = "project/loadbalancers/_vip_details.html"
 
     def get_context_data(self, request):
-        vip = self.tab_group.kwargs['vip']
+        vid = self.tab_group.kwargs['vip_id']
+        try:
+            vip = api.lbaas.vip_get(request, vid)
+        except:
+            vip = []
+            exceptions.handle(self.tab_group.request,
+                              _('Unable to retrieve vip details.'))
         return {'vip': vip}
 
 
@@ -117,7 +124,13 @@ class MemberDetailsTab(tabs.Tab):
     template_name = "project/loadbalancers/_member_details.html"
 
     def get_context_data(self, request):
-        member = self.tab_group.kwargs['member']
+        mid = self.tab_group.kwargs['member_id']
+        try:
+            member = api.lbaas.member_get(request, mid)
+        except:
+            member = []
+            exceptions.handle(self.tab_group.request,
+                              _('Unable to retrieve member details.'))
         return {'member': member}
 
 
@@ -127,7 +140,13 @@ class MonitorDetailsTab(tabs.Tab):
     template_name = "project/loadbalancers/_monitor_details.html"
 
     def get_context_data(self, request):
-        monitor = self.tab_group.kwargs['monitor']
+        mid = self.tab_group.kwargs['monitor_id']
+        try:
+            monitor = api.lbaas.pool_health_monitor_get(request, mid)
+        except:
+            monitor = []
+            exceptions.handle(self.tab_group.request,
+                              _('Unable to retrieve monitor details.'))
         return {'monitor': monitor}
 
 
