@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012 NEC Corporation
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -12,13 +14,15 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.urls import re_path
+from django.conf.urls.defaults import patterns, url
 
-from openstack_dashboard.dashboards.project.networks.subnets import views
+from .views import DetailView
 
 
 SUBNETS = r'^(?P<subnet_id>[^/]+)/%s$'
+VIEW_MOD = 'openstack_dashboard.dashboards.project.networks.subnets.views'
 
-urlpatterns = [
-    re_path(SUBNETS % 'detail', views.DetailView.as_view(), name='detail'),
-]
+
+urlpatterns = patterns(VIEW_MOD,
+    url(SUBNETS % 'detail', DetailView.as_view(), name='detail')
+)
