@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012,  Nachi Ueno,  NTT MCL,  Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -12,12 +14,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.urls import re_path
+from django.conf.urls.defaults import patterns, url
 
-from openstack_dashboard.dashboards.project.routers.ports import views
+from .views import DetailView
 
 PORTS = r'^(?P<port_id>[^/]+)/%s$'
 
-urlpatterns = [
-    re_path(PORTS % 'detail', views.DetailView.as_view(), name='detail'),
-]
+urlpatterns = patterns('horizon.dashboards.project.networks.ports.views',
+    url(PORTS % 'detail', DetailView.as_view(), name='detail'))
